@@ -15,11 +15,6 @@
 ### snow::MPI
 ###
 
-bprunMPIslave <- function() {
-    .Deprecated("bprunMPIworker")
-    bprunMPIworker()
-}
-
 bprunMPIworker <- function() {
     comm <- 1
     intercomm <- 2
