@@ -68,7 +68,7 @@ result <- bptry(bplapply(list(1, "2", 3), sqrt, BPPARAM=param))
 bpok(result)
 
 ## ----errors_traceback------------------------------------------------------
-tail(attr(result[[which(!bpok(result))]], "traceback"))
+attr(result[[which(!bpok(result))]], "traceback")
 
 ## ----redo_error------------------------------------------------------------
 X <- list(1, "2", 3)
