@@ -17,7 +17,7 @@ test_MulticoreParam_bpforceGC <- function() {
     if (.Platform$OS.type == "windows")
         return()
 
-    checkIdentical(TRUE, bpforceGC(MulticoreParam()))
+    checkIdentical(FALSE, bpforceGC(MulticoreParam()))
     checkIdentical(FALSE, bpforceGC(MulticoreParam(force.GC = FALSE)))
     checkIdentical(TRUE, bpforceGC(MulticoreParam(force.GC = TRUE)))
     checkException(MulticoreParam(force.GC = NA), silent = TRUE)
