@@ -107,57 +107,3 @@ test_rename <- function() {
     checkIdentical(exp, .rename(exp0, X))
 }
 
-test_mrename <- function() {
-    .mrename <- BiocParallel:::.mrename
-
-    ## list() when `mapply()` invoked with no arguments, `mapply(identity)`
-    X <- list()
-    checkIdentical(X, .mrename(list(), X))
-
-    ## list(X) when `mapply()` invoked with one argument, `mapply(identity, X)`
-    XX <- list(X)
-    checkIdentical(list(), .mrename(list(), XX))
-
-    ## `mapply(identity, character())` returns a _named_ list()
-    X <- character()
-    XX <- list(X)
-    checkIdentical(setNames(list(), character()), .mrename(list(), XX))
-
-    ## named arguments to mapply() are _not_ names of return value...
-    X = list()
-    XX <- list(x = X)
-    checkIdentical(list(), .mrename(list(), XX))
-
-    ## ...except if the argument is a character()
-    X <- character()
-    XX <- list(x = X)
-    checkIdentical(setNames(list(), character()), .mrename(list(), XX))
-
-    ## with multiple arguments, names are from the first argument
-    XX = list(c(a = 1, b = 2, c = 3), c(d = 4, e = 5, f = 6))
-    checkIdentical(
-        setNames(list(1, 2, 3), letters[1:3]),
-        .mrename(list(1, 2, 3), XX)
-    )
-
-    ## ...independent of names on the arguments
-    XX = list(A = c(a = 1, b = 2, c = 3), B = c(d = 4, e = 5, f = 6))
-    checkIdentical(
-        setNames(list(1, 2, 3), letters[1:3]),
-        .mrename(list(1, 2, 3), XX)
-    )
-
-    ## when the first argument is an unnamed character vector, names are values
-    XX = list(A = letters[1:3], B = 1:3)
-    checkIdentical(
-        setNames(list(1, 2, 3), letters[1:3]),
-        .mrename(list(1, 2, 3), XX)
-    )
-
-    ## ...except if there are names on the first vector...
-    XX = list(A = setNames(letters[1:3], LETTERS[1:3]), B = 1:3)
-    checkIdentical(
-        setNames(list(1, 2, 3), LETTERS[1:3]),
-        .mrename(list(1, 2, 3), XX)
-    )
-}
